import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_aes_ecb_pkcs5/flutter_aes_ecb_pkcs5.dart';
import 'package:intl/intl.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:http/http.dart' as http;

String loadAsset(String asset) {
  return "packages/mobile_pos/assets/images/$asset";
}

Future<dynamic> pushRoute(BuildContext context, Widget page) async {
  Navigator.push(
    context,
    MaterialPageRoute(
      builder: (context) => page,
    ),
  );
  return;
}

Future<dynamic> replaceRoute(BuildContext context, Widget page) async {
  Navigator.pushReplacement(
    context,
    MaterialPageRoute(
      builder: (context) => page,
    ),
  );
  return;
}

Future<void> toRavenPayHome(BuildContext context) async {
  Navigator.popUntil(context, ModalRoute.withName("raven_pay"));
  return;
}

String formatAmount(double amount) {
  var fmt = NumberFormat('#,###.##', 'en_US');

  return fmt.format(amount);
}

Future<String?> encryptString(String data) async {
  var encryptText = await FlutterAesEcbPkcs5.encryptString(data, eKey);
  return encryptText;
}

Future<String?> decryptString(String data) async {
  var decryptText = await FlutterAesEcbPkcs5.decryptString(data, eKey);
  return decryptText;
}

void showSnack(BuildContext context, String msg, {SnackBarBehavior? floating}) {
  ScaffoldMessenger.of(context).showSnackBar(SnackBar(
    margin: const EdgeInsets.symmetric(horizontal: 16, vertical: 4),
    backgroundColor: Colors.black,
    behavior: SnackBarBehavior.floating,
    content: Text(
      msg,
      textAlign: TextAlign.start,
      style: bodyText.copyWith(fontSize: 14.0, color: Colors.white),
    ),
  ));
}

String? validateInput(String? data, {String? errorMessage, int minCount = 4}) {
  if (data!.trim().length < minCount) {
    return errorMessage ?? 'Invalid input';
  } else {
    return null;
  }
}

String getMid(context) {
  var param = keyDetails!.paramdownload!;
  param = param.substring(24, 39);
  return param;
}

String getBusinessName(context) {
  var param = keyDetails!.paramdownload!;
  return param.substring(param.length - 40, param.length);
}

void copyToClipBoard(BuildContext context,
    {required String data, String? msg}) async {
  await Clipboard.setData(ClipboardData(text: data));
  showSnack(context, msg ?? 'Text Copied!');
}

String refineMeaning(response) {
  String message = '';

  if (response == 'failed') {
    message = 'Failed - TimeOut';
    return message;
  }

  if (response['data']['data'] != null) {
    message = response['data']['data']['meaning'].toString();
  }

  if (message.isEmpty) {
    if (response['data']['meaning'] != null) {
      message = response['data']['meaning'].toString();
    }
  }

  if (message.isEmpty) {
    if (response['data']['message'] != null) {
      message = response['data']['message'].toString();
    } else {
      message = 'Reason unknown';
    }
  }

  return message;
}

Future<bool> checkInternetConnection() async {
  try {
    var response = await http
        .get(Uri.parse(pluginConfig.isStaging ? baseURLDev : baseURLProd));
    if (response.statusCode == 200) {
      return true;
    } else {
      // Request failed, which may indicate no internet connection
      return false;
    }
  } catch (e) {
    // An error occurred, which may indicate no internet connection
    return false;
  }
}

extension StringExtension on String {
  String capitalize() {
    List<String> splitted = split(" ");
    for (int x = 0; x < splitted.length; x++) {
      if (splitted[x].isEmpty) {
        splitted[x] = splitted[x];
        continue;
      }
      splitted[x] =
          "${splitted[x][0].toUpperCase()}${splitted[x].substring(1).toLowerCase()}";
    }

    return splitted.fold<String>(
        "", (previousValue, element) => "$previousValue$element ");
  }
}
