// ignore_for_file: use_build_context_synchronously

import 'dart:io';
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/mobile_pos_method_channel.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/raven_const.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/device_disconnect_sheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/shared_widgets/powerby_by_raven_widget.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_amount_pad.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/views/card_payment/connect_bluetooth.dart';
import 'package:mobile_pos/src/views/card_payment/insert_card.dart';
import '../../mobile_pos_platform_interface.dart';
import '../../mobile_pos_sdk.dart';

class PurchaseAmount extends StatefulWidget {
  final String? title;
  const PurchaseAmount({super.key, this.title});

  @override
  State<PurchaseAmount> createState() => _PurchaseAmountState();
}

class _PurchaseAmountState extends State<PurchaseAmount> {
  String amount = "";
  bool isBusy = false;

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
      body: Column(
        children: [
          const Gap(24),
          Padding(
            padding: EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
            child: Column(
              children: [
                Row(children: [
                  const Expanded(
                    child: RavenPayCloseButton(
                      isArrow: true,
                      text: "",
                    ),
                  ),
                  ValueListenableBuilder(
                      valueListenable:
                          MethodChannelMobilePos.bluetoothConnected,
                      builder: (context, widget, child) {
                        return !MethodChannelMobilePos.bluetoothConnected.value
                            ? const SizedBox()
                            : GestureDetector(
                                onTap: () {
                                  showRavenPayBottomSheet(context,
                                      child: DeviceDisconnectSheet(
                                        onPressed: () async {
                                          Navigator.pop(context);
                                          MobilePosPlatform.instance
                                              .disconnectBluetoothDevice();
                                        },
                                        deviceName:
                                            pluginConfig.appInfo.deviceName ??
                                                "",
                                      ));
                                },
                                child: Container(
                                    padding: const EdgeInsets.symmetric(
                                        horizontal: 12, vertical: 4),
                                    decoration: BoxDecoration(
                                        color: const Color(0xfff7f8f7),
                                        borderRadius:
                                            BorderRadius.circular(12)),
                                    child: Row(
                                      children: [
                                        Image.asset(
                                            loadAsset("bluethoot_icon.png"),
                                            height: 16),
                                        const Gap(4),
                                        Text(
                                            pluginConfig.appInfo.deviceName ??
                                                "",
                                            style: bodyText.copyWith(
                                                fontWeight: FontWeight.w500,
                                                fontSize: 14,
                                                color: Colors.black)),
                                        const Gap(4),
                                        Container(
                                          height: 6,
                                          width: 6,
                                          decoration: BoxDecoration(
                                              shape: BoxShape.circle,
                                              color: AppColors.bankBoxGreen),
                                        )
                                      ],
                                    )),
                              );
                      })
                ]),
                const Gap(24),
                Row(
                  children: [
                    Expanded(
                        child: Text(widget.title ?? "Enter Amount",
                            style: headling1)),
                  ],
                ),
                const Gap(70),
                Align(
                    alignment: Alignment.center,
                    child: RichText(
                        text: TextSpan(
                            text: '₦',
                            style: headling1.copyWith(
                                fontFamily: 'Roboto',
                                fontSize: 38,
                                fontWeight: FontWeight.bold),
                            children: [
                          TextSpan(
                              text: amount.isEmpty
                                  ? "0.00"
                                  : formatAmount(double.tryParse(amount) ?? 0),
                              style: headling1.copyWith(fontSize: 38))
                        ]))),
                const Gap(24),
              ],
            ),
          ),
          const Gap(24),
          RavenPayAmountPad(
              onChange: (val) {
                amount = val;
                setState(() {});
              },
              amount: amount),
          const Gap(24),
          Padding(
            padding: EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
            child: RavenPayButton(
              busy: isBusy,
              enabled: amount.isNotEmpty,
              buttonText: "Proceed",
              onPressed: () async {
                isBusy = true;
                setState(() {});
                bool internet = await checkInternetConnection();
                if (!internet) {
                  isBusy = false;
                  setState(() {});
                  showSnack(context,
                      'No internet connectivity, please connect to internet to proceed');
                  return;
                }

                if (internet) {
                  if (keyDetails == null) {
                    var status = await ApiRequests.fetchAppInfoBool(context);

                    if (!status) {
                      isBusy = false;
                      setState(() {});
                      showSnack(context,
                          'No credential found, click proceed to download');
                      return;
                    }
                  }
                }

                try {
                  var val = double.tryParse(amount);
                  if (val! <= 0) {
                    return;
                  }
                  isBusy = true;
                  setState(() {});
                  processPayment();

                  //widget.onProceed(context, val);
                } catch (ex) {
                  return;
                }
              },
            ),
          ),
          const Gap(20),
          const PoweredByRaven(
            fontSize: 9,
          ),
        ],
      ),
    );
  }

  void makeButtonClickable() {
    isBusy = false;
    setState(() {});
  }

  void processPayment() async {
    if (Platform.isAndroid) {
      var response = await MobilePosPlatform.instance.initLocationStatus();

      if (!response) {
        isBusy = false;
        setState(() {});
        return;
      }
    }
    var response = await MobilePosPlatform.instance.chargeCard(context,
        amount: double.parse(amount),
        accountType: '00',
        connectivityType: ConnectivityType.bluetooth);
    makeButtonClickable();
    if (response.toString().toUpperCase() == "REINIT") {
      pushRoute(
          context,
          InsertCard(
            paymentType: PaymentType.card,
            deviceName: pluginConfig.appInfo.deviceName ?? "",
            amount: double.tryParse(amount) ?? 0.0,
          ));
      return;
    }
    pushRoute(
        context,
        ConnectBluetooth(
          amount: double.tryParse(amount) ?? 0.0,
        ));
  }
}
