import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/mobile_pos.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class RavenPayCloseButton extends StatelessWidget {
  final bool isArrow;
  final String text;
  final Color? color;
  final List<BoxShadow>? boxShadow;
  final Function? onBackPressed;
  const RavenPayCloseButton({
    super.key,
    this.text = "Close",
    this.boxShadow,
    this.onBackPressed,
    this.color,
    this.isArrow = false,
  });

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () {
        if (!isArrow) {
          RavenBankBoxPlugin.close(context);
          return;
        }
        if (onBackPressed == null) {
          Navigator.pop(context);
          return;
        }
        onBackPressed!();
      },
      child: Row(
        children: [
          Container(
              padding: const EdgeInsets.all(9),
              height: 32,
              width: 32,
              decoration: BoxDecoration(
                  boxShadow: color == null
                      ? boxShadow ??
                          [
                            const BoxShadow(
                                color: Color(0xffe2e2e2),
                                spreadRadius: 2,
                                offset: Offset(2, 2),
                                blurRadius: 24)
                          ]
                      : null,
                  shape: BoxShape.circle,
                  color: color ?? pluginTheme.onPrimary),
              child: Image.asset(
                  loadAsset(isArrow ? "arrow_back.png" : "close_icon.png"),
                  color: isArrow ? null : pluginTheme.onPrimary)),
          const Gap(12),
          Text(
            text,
            style: subtitle.copyWith(
                color: isArrow ? (color) : (pluginTheme.onPrimary)),
          )
        ],
      ),
    );
  }
}
