// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/mobile_pos_platform_interface.dart';
import 'package:mobile_pos/src/helpers/enums.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/helpers/logger.dart';
import 'package:mobile_pos/src/models/raven_const.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/card_payment/connect_bluetooth.dart';
import 'package:mobile_pos/src/views/card_payment/insert_card.dart';
import 'package:mobile_pos/src/views/home/widget/payment_method_bottomsheet.dart';
import 'package:mobile_pos/src/views/home/widget/home_item.dart';
import 'package:mobile_pos/src/views/network_stability/network_status_sheet.dart';
import 'package:mobile_pos/src/views/request_pos/request_terminal_index.dart';
import 'package:mobile_pos/src/shared_widgets/powerby_by_raven_widget.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';

class RavenPayApp extends StatefulWidget {
  const RavenPayApp({super.key});

  @override
  State<RavenPayApp> createState() => _RavenPayAppState();
}

class _RavenPayAppState extends State<RavenPayApp> {
  @override
  void initState() {
    super.initState();
    logData("init here");
    initialize();
  }

  Future<void> initKeys() async {
    if (keyDetails == null) {
      await ApiRequests.fetchAppInfoBool(context);
    }
  }

  void initialize() async {
    await ApiRequests.fetchAppInfo();
    await ApiRequests.registerUser();
  }

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
      backgroundColor: pluginTheme.primaryColor,
      body: Padding(
        padding: EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
        child: Column(
          children: [
            const Gap(12),
            Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                RavenPayCloseButton(
                  color: Colors.white.withOpacity(0.2),
                  boxShadow: [
                    BoxShadow(
                        color: const Color(0xff333333).withOpacity(0.06),
                        spreadRadius: 2,
                        offset: const Offset(2, 2),
                        blurRadius: 2)
                  ],
                )
              ],
            ),
            const Spacer(),
            Align(
                alignment: Alignment.topLeft,
                child: SizedBox(
                    height: 48,
                    width: 48,
                    child: pluginConfig.logo ??
                        ClipOval(
                          child: Container(
                            decoration: BoxDecoration(
                                color: pluginConfig.theme!.secondaryColor),
                            child: Center(
                              child: Text(
                                pluginConfig.appInfo.appName[0],
                                style: headling1.copyWith(
                                    color: pluginConfig.theme!.onPrimary),
                              ),
                            ),
                          ),
                        ))),
            const Gap(24),
            Text(
                "Hi ${pluginConfig.customerInfo.firstName}, process payments much easier with ${pluginConfig.appInfo.appName}",
                style: headling1.copyWith(color: pluginTheme.onPrimary)),
            const Gap(32),
            Container(
              padding: const EdgeInsets.symmetric(vertical: 12),
              decoration: BoxDecoration(
                  color: Colors.white, borderRadius: BorderRadius.circular(18)),
              child: Column(children: [
                HomeItem(
                    onTap: () {
                      showRavenPayBottomSheet(context,
                          child: const PaymentMethod());
                    },
                    asset: "receive_payment.png",
                    title: "Process Payment",
                    subTitile: "Accept payment from your customers"),
                // HomeItem(
                //     onTap: () {
                //       pushRoute(context, const AddCardPin());
                //     },
                //     asset: "secure_pin.png",
                //     title: "Secure PIN Share",
                //     subTitile: "Securely share card PIN for payment"),
                if (pluginConfig.showTerminals) ...[
                  HomeItem(
                      onTap: () {
                        pushRoute(context, const RequestTerminalIndex());
                      },
                      comingSoon: false,
                      asset: "terminal_icon.png",
                      title: "Terminals",
                      subTitile: "Manage your point of sales terminals"),
                ],
                if (pluginConfig.enableBalanceCheck) ...[
                  HomeItem(
                      onTap: () async {
                        await initKeys();
                        var response = await MobilePosPlatform.instance
                            .chargeCard(context,
                                amount: 10.0,
                                accountType: '00',
                                connectivityType: ConnectivityType.bluetooth);
                        if (response.toString().toUpperCase() == "REINIT") {
                          pushRoute(
                              context,
                              InsertCard(
                                paymentType: PaymentType.checkBalance,
                                deviceName:
                                    pluginConfig.appInfo.deviceName ?? "",
                                amount: 10.0,
                              ));
                          return;
                        }
                        pushRoute(
                            context,
                            const ConnectBluetooth(
                              paymentType: PaymentType.checkBalance,
                              amount: 10.0,
                            ));
                      },
                      comingSoon: false,
                      asset: "card_balance.png",
                      title: "Check Balance",
                      subTitile: "View ATM card balance"),
                ],
                HomeItem(
                    comingSoon: true,
                    onTap: () {},
                    asset: "generate_pay_code.png",
                    title: "Generate Paycode",
                    subTitile: "Receive payment from a third-party terminal"),
                HomeItem(
                    onTap: () {
                      showRavenPayBottomSheet(context,
                          child: const NetworkStatusSheet());
                    },
                    asset: "network_settings.png",
                    title: "Network Settings",
                    subTitile: "Manage connectivity and network update."),
              ]),
            ),
            const Gap(32),
            const PoweredByRaven(
              transparent: true,
            ),
            const Gap(24),
          ],
        ),
      ),
    );
  }
}
