import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/shared_widgets/coming_soon_badge.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/request_pos/widget/termianl_settings.dart';
import 'package:share_plus/share_plus.dart';

class TerminalInfoScreen extends StatefulWidget {
  final TerminalModel model;
  const TerminalInfoScreen({super.key, required this.model});

  @override
  State<TerminalInfoScreen> createState() => _TerminalInfoScreenState();
}

class _TerminalInfoScreenState extends State<TerminalInfoScreen> {
  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        showLogo: pluginConfig.showLabel,
        body: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Gap(24),
              Row(
                children: [
                  const RavenPayCloseButton(
                    text: "",
                    isArrow: true,
                  ),
                  const Spacer(),
                  GestureDetector(
                    onTap: () {
                      showRavenPayBottomSheet(context,
                          child: TerminalSettings(
                            model: widget.model,
                            onUpdated: () {
                              setState(() {});
                            },
                          ));
                    },
                    child: Container(
                      height: 32,
                      width: 32,
                      padding: const EdgeInsets.all(7),
                      decoration: BoxDecoration(
                          color: Colors.white,
                          shape: BoxShape.circle,
                          boxShadow: [
                            BoxShadow(
                                color: const Color(0xffe2e2e2).withOpacity(0.8),
                                spreadRadius: 2,
                                blurRadius: 12)
                          ]),
                      child: Image.asset(
                        loadAsset("settings_icon.png"),
                        height: 16,
                      ),
                    ),
                  )
                ],
              ),
              const Gap(24),
              Hero(
                tag: widget.model.tid ?? "",
                child: Text(
                  (widget.model.tidLabel ?? "").toUpperCase(),
                  style: headling1.copyWith(fontSize: 24),
                ),
              ),
              const Gap(12),
              CardWidget(model: widget.model),
              const Gap(24),
              Container(
                  padding:
                      const EdgeInsets.symmetric(horizontal: 16, vertical: 20),
                  width: double.infinity,
                  decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(12),
                      color: Colors.white,
                      boxShadow: [
                        BoxShadow(
                            color: const Color(0xffe2e2e2).withOpacity(0.5),
                            blurRadius: 34,
                            spreadRadius: 2)
                      ]),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      ItemWidget(
                        name: "Serial Number",
                        value: widget.model.serial ?? "",
                      ),
                      const Gap(24),
                      ItemWidget(
                        name: "Terminal ID",
                        value: widget.model.tid ?? "",
                      ),
                      const Gap(24),
                      Container(
                          padding: const EdgeInsets.symmetric(horizontal: 16),
                          width: double.infinity,
                          height: 54,
                          decoration: BoxDecoration(
                              border: Border.all(
                                  color: AppColors.borderGrey, width: 1),
                              color: AppColors.ravenLightGrey4,
                              borderRadius: BorderRadius.circular(12)),
                          child: Row(
                            children: [
                              Expanded(
                                  child: FittedBox(
                                child: Text("View Terminal Transaction",
                                    style: subtitle.copyWith(fontSize: 12)),
                              )),
                              const Gap(12),
                              const ComingSoonBadge(),
                            ],
                          ))
                    ],
                  ))
            ],
          ),
        ));
  }
}

class ItemWidget extends StatelessWidget {
  final String name;
  final String value;
  const ItemWidget({super.key, required this.value, required this.name});

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(name,
            style: subtitle.copyWith(
                fontWeight: FontWeight.w500, fontSize: 12, letterSpacing: 0.3)),
        const Gap(4),
        Text(value,
            style: subtitle.copyWith(
                fontSize: 14, color: Colors.black, fontWeight: FontWeight.w800))
      ],
    );
  }
}

class CardWidget extends StatelessWidget {
  final TerminalModel model;
  const CardWidget({super.key, required this.model});

  @override
  Widget build(BuildContext context) {
    return ClipRRect(
      borderRadius: BorderRadius.circular(16),
      child: Container(
          width: double.infinity,
          decoration: BoxDecoration(
              image: DecorationImage(
                  image: AssetImage(loadAsset("terminal_info_card_bg.png"))),
              color: pluginConfig.theme!.primaryColor),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Padding(
                padding:
                    const EdgeInsets.symmetric(horizontal: 14, vertical: 14),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text("CASH IN",
                        style: subtitle.copyWith(
                            color:
                                pluginConfig.theme!.onPrimary.withOpacity(0.8),
                            fontSize: 12)),
                    const Gap(4),
                    RavenPayMoneyWidget(
                      amount: "908120.00",
                      fontSize: 20,
                      color: pluginConfig.theme!.onPrimary,
                    ),
                  ],
                ),
              ),
              if (model.accountNumber != null &&
                  model.accountNumber!.isNotEmpty) ...[
                const Gap(12),
                Container(
                    padding:
                        const EdgeInsets.symmetric(horizontal: 12, vertical: 9),
                    width: double.infinity,
                    decoration:
                        BoxDecoration(color: Colors.black.withOpacity(0.4)),
                    child: Row(
                      children: [
                        Image.asset(
                          loadAsset("wema_logo.png"),
                          height: 22,
                        ),
                        const Gap(12),
                        Expanded(
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Text(
                                "${model.accountNumber} *  ${model.accountName}",
                                overflow: TextOverflow.ellipsis,
                                maxLines: 1,
                                style: subtitle.copyWith(
                                    fontWeight: FontWeight.w500,
                                    color: pluginConfig.theme!.onPrimary),
                              ),
                              const Gap(2),
                              Text(model.bank.toString(),
                                  style: subtitle.copyWith(
                                      color: pluginConfig.theme!.onPrimary
                                          .withOpacity(0.8),
                                      fontWeight: FontWeight.w400,
                                      fontSize: 10)),
                            ],
                          ),
                        ),
                        const Gap(24),
                        GestureDetector(
                          onTap: () {
                            Share.share(
                                "${model.accountName ?? ""} ${model.accountNumber ?? ""} ${model.bank ?? ""}");
                          },
                          child: Container(
                              height: 28,
                              width: 28,
                              padding: const EdgeInsets.all(8),
                              decoration: BoxDecoration(
                                  shape: BoxShape.circle,
                                  color: Colors.black.withOpacity(0.2)),
                              child: Image.asset(loadAsset("share_icon.png"))),
                        )
                      ],
                    )),
              ]
            ],
          )),
    );
  }
}
